# Sparse representation with Gaussian atoms

We introduce advanced sparse representation and dictionary learning algorithms, specifically designed for dictionaries where the atoms exhibit Gaussian probability distributions centered around pivotal atoms. These algorithms are particularly adept at anomaly detection, with a distinct advantage in detecting a unique anomaly type termed "dependency".

In this project, we will extensively benchmark and assess the performance of our proposed algorithms: `Gaussian Orthogonal Matching Pursuit (Gauss-OMP)` and `Gaussian Dictionary Learning (DL-Gauss-OMP)`.

## Introduction

The given Python script runs benchmark tests on our machine learning algorithms, particularly `Gauss-OMP` and `DL-Gauss-OMP`. This is executed across multiple datasets specified in the `mat_file_list`. The script then evaluates the performance of these algorithms based on metrics such as ROC and precision, and stores these results in corresponding `.csv` files. This program was adapted following the PyOD example.

## Dependencies

- Python 3+
- Numpy
- Pandas
- Scikit-learn
- scipy
- [pyod](https://github.com/yzhao062/pyod) (Python Outlier Detection)

## Usage

1. Ensure all dependencies are installed.

2. Place your dataset `.mat` files in the `dependency_mats` directory. The datasets are available on our site [asydil](https://asydil.upb.ro/software/).

3. Configure the parameters at the beginning of the script, such as:
       - `n_components_features_ratio_list`
       - `n_nonzero_coefs_list`
       - `max_iter_list`
       - `lambda_list`
       - `sigmas_list`

4. Run the script:

   ```python3 benchmark_script.py```

5. Check the `results` directory for the generated `.csv` files, which will contain the benchmarking data.

## Results

The results are stored in `.csv` files within the `results` directory. They are organized as:

- `roc_[parameters].csv`: Contains the ROC results.
- `time_[parameters].csv`: Contains the execution time for each algorithm.
- `prc_[parameters].csv`: Contains the precision results.

## Citing Us

This represents the main resources necessary for reproducing the results presented in “Sparse representation with Gaussian atoms”, by Denis C. Ilie Ablachim, Andra Baltoiu and Bogdan Dumitrescu. If you use our work please cite the following paper

```
@inproceedings{ilie2023sparse,
  title={Sparse representation with Gaussian atoms},
  author={Ilie-Ablachim, Denis C and Baltoiu, Andra and Dumitrescu, Bogdan},
  booktitle={IEEE International Conference on Acoustics, Speech and Signal Processing (ICASSP) - submitted},
  year={2023},
  organization={IEEE}
}
```

## Funding

This work is supported by a grant of the Ministry of Research, Innovation and Digitization, CNCS – UEFISCDI, project number PN-III-P4-PCE-2021-0154, within PNCDI III.


This `README.md` provides an overview of the script, its dependencies, how to use it, and what results to expect. Adjustments might be required to better fit the exact needs or specifications of the project.